pub(crate) fn parse_args(attr: TokenStream) -> Result<Punctuated<Meta, Comma>>Expand description
Parses a macro’s own arguments, all of which are forwarded to the attribute it stands in for.
pub(crate) fn parse_args(attr: TokenStream) -> Result<Punctuated<Meta, Comma>>Parses a macro’s own arguments, all of which are forwarded to the attribute it stands in for.